@@ -75,6 +75,6 @@ def test_block_track_latest(
     tt = TxCache.load()
     print(tt)
 
-    assert(tt.tx_number == 13)
+    assert(tt.tx_index == 13)
     assert(tt.block_number == 42)
 
